==> WHLX_CMS-0.03alpha.zip: whlx/library/formdata.php <==
<?php
// 
// WHLX CMS - formdata.php
// 
// 20040330 - 0.00 alpha
// 20040402 - 0.02 alpha    名称変更:whlx_formdata.php -> formdata.php etc. 
// 




class  WHLX_Formdata
{
	var $form;        // 
	var $header;      // 
	var $pathinfo;    // 

	function WHLX_Formdata()
	{
		if( phpversion() <  "4.1.0" )
		{
			$_SERVER   =  $HTTP_SERVER_VARS;    // $_SERVER  は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_SERVER_VARS  を使います. 
			$_ENV      =  $HTTP_ENV_VARS;       // $_ENV     は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_ENV_VARS     を使います. 
			$_COOKIE   =  $HTTP_COOKIE_VARS;    // $_COOKIE  は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_COOKIE_VARS  を使います. 
			$_GET      =  $HTTP_GET_VARS;       // $_GET     は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_GET_VARS     を使います. 
			$_POST     =  $HTTP_POST_VARS;      // $_POST    は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_POST_VARS    を使います. 
			$_FILES    =  $HTTP_POST_FILES;     // $_FILES   は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_POST_FILES   を使います. 
			$_SESSION  =  $HTTP_SESSION_VARS;   // $_SESSION は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_SESSION_VARS を使います. 
		//	$_REQUEST  =  $                     // $_REQUEST は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では代用物がありません. 
		}
		else // ( phpversion() >= "4.1.0" )
		{
		}

		$this->header      =  array     
		(                                
			"_SERVER"  => $_SERVER,  
			"_ENV"     => $_ENV,     
			"_COOKIE"  => $_COOKIE,  
			"_GET"     => $_GET,     
			"_POST"    => $_POST,    
			"_FILES"   => $_FILES,   
			"_SESSION" => $_SESSION  
		);

		$this->pathinfo    =  explode( '/', $_ENV[ 'PATH_INFO' ] );
		$this->pathinfo[0] =  $_ENV[ 'PATH_INFO' ];

		$this->form        =  array_merge( $this->pathinfo, $_GET, $_POST );
	}

	function  form  (){ return $this->form;   }
	function  header(){ return $this->header; }

}




?>

==> WHLX_CMS-0.11alpha.zip: whlx/library/formdata.php <==
<?php
// 
// WHLX CMS - formdata.php
// 
// 20040330 - 0.00 alpha
// 20040402 - 0.02 alpha    名称変更:whlx_formdata.php -> formdata.php etc. 
// 




class  WHLX_Formdata
{
	var $form;        // 
	var $header;      // 
	var $pathinfo;    // 

	function WHLX_Formdata()
	{
		if( phpversion() <  "4.1.0" )
		{
			$_SERVER   =  $HTTP_SERVER_VARS;    // $_SERVER  は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_SERVER_VARS  を使います. 
			$_ENV      =  $HTTP_ENV_VARS;       // $_ENV     は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_ENV_VARS     を使います. 
			$_COOKIE   =  $HTTP_COOKIE_VARS;    // $_COOKIE  は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_COOKIE_VARS  を使います. 
			$_GET      =  $HTTP_GET_VARS;       // $_GET     は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_GET_VARS     を使います. 
			$_POST     =  $HTTP_POST_VARS;      // $_POST    は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_POST_VARS    を使います. 
			$_FILES    =  $HTTP_POST_FILES;     // $_FILES   は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_POST_FILES   を使います. 
			$_SESSION  =  $HTTP_SESSION_VARS;   // $_SESSION は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では HTTP_SESSION_VARS を使います. 
		//	$_REQUEST  =  $                     // $_REQUEST は, PHP 4.1.0 以降では定義済の変数であり, 予約語です. PHP 4.1.0 以前では代用物がありません. 
		}
		else // ( phpversion() >= "4.1.0" )
		{
		}

		$this->header      =  array     
		(                                
			"_SERVER"  => $_SERVER,  
			"_ENV"     => $_ENV,     
			"_COOKIE"  => $_COOKIE,  
			"_GET"     => $_GET,     
			"_POST"    => $_POST,    
			"_FILES"   => $_FILES,   
			"_SESSION" => $_SESSION  
		);

		$this->pathinfo    =  explode( '/', $_ENV[ 'PATH_INFO' ] );
		$this->pathinfo[0] =  $_ENV[ 'PATH_INFO' ];

		$this->form        =  array_merge( $this->pathinfo, $_GET, $_POST );    // POSTもGETも拡張パスも, すべて纏める
	//	$this->form        =  array_merge( $_POST );                            // POSTのみ受付
	}

	function  form  (){ return $this->form;   }
	function  header(){ return $this->header; }

}




?>
